==> mingw-w64-clang-aarch64-geographiclib-1.52-2-any.pkg.tar.zst: clangarm64/share/doc/GeographicLib/html/namespaceGeographicLib.js <==
var namespaceGeographicLib =
[
    [ "Accumulator", "classGeographicLib_1_1Accumulator.html", "classGeographicLib_1_1Accumulator" ],
    [ "AlbersEqualArea", "classGeographicLib_1_1AlbersEqualArea.html", "classGeographicLib_1_1AlbersEqualArea" ],
    [ "AzimuthalEquidistant", "classGeographicLib_1_1AzimuthalEquidistant.html", "classGeographicLib_1_1AzimuthalEquidistant" ],
    [ "CassiniSoldner", "classGeographicLib_1_1CassiniSoldner.html", "classGeographicLib_1_1CassiniSoldner" ],
    [ "CircularEngine", "classGeographicLib_1_1CircularEngine.html", "classGeographicLib_1_1CircularEngine" ],
    [ "Constants", "classGeographicLib_1_1Constants.html", "classGeographicLib_1_1Constants" ],
    [ "DMS", "classGeographicLib_1_1DMS.html", "classGeographicLib_1_1DMS" ],
    [ "Ellipsoid", "classGeographicLib_1_1Ellipsoid.html", "classGeographicLib_1_1Ellipsoid" ],
    [ "EllipticFunction", "classGeographicLib_1_1EllipticFunction.html", "classGeographicLib_1_1EllipticFunction" ],
    [ "GARS", "classGeographicLib_1_1GARS.html", "classGeographicLib_1_1GARS" ],
    [ "Geocentric", "classGeographicLib_1_1Geocentric.html", "classGeographicLib_1_1Geocentric" ],
    [ "GeoCoords", "classGeographicLib_1_1GeoCoords.html", "classGeographicLib_1_1GeoCoords" ],
    [ "Geodesic", "classGeographicLib_1_1Geodesic.html", "classGeographicLib_1_1Geodesic" ],
    [ "GeodesicExact", "classGeographicLib_1_1GeodesicExact.html", "classGeographicLib_1_1GeodesicExact" ],
    [ "GeodesicLine", "classGeographicLib_1_1GeodesicLine.html", "classGeographicLib_1_1GeodesicLine" ],
    [ "GeodesicLineExact", "classGeographicLib_1_1GeodesicLineExact.html", "classGeographicLib_1_1GeodesicLineExact" ],
    [ "GeographicErr", "classGeographicLib_1_1GeographicErr.html", "classGeographicLib_1_1GeographicErr" ],
    [ "Geohash", "classGeographicLib_1_1Geohash.html", "classGeographicLib_1_1Geohash" ],
    [ "Geoid", "classGeographicLib_1_1Geoid.html", "classGeographicLib_1_1Geoid" ],
    [ "Georef", "classGeographicLib_1_1Georef.html", "classGeographicLib_1_1Georef" ],
    [ "Gnomonic", "classGeographicLib_1_1Gnomonic.html", "classGeographicLib_1_1Gnomonic" ],
    [ "GravityCircle", "classGeographicLib_1_1GravityCircle.html", "classGeographicLib_1_1GravityCircle" ],
    [ "GravityModel", "classGeographicLib_1_1GravityModel.html", "classGeographicLib_1_1GravityModel" ],
    [ "JacobiConformal", "classGeographicLib_1_1JacobiConformal.html", "classGeographicLib_1_1JacobiConformal" ],
    [ "LambertConformalConic", "classGeographicLib_1_1LambertConformalConic.html", "classGeographicLib_1_1LambertConformalConic" ],
    [ "LocalCartesian", "classGeographicLib_1_1LocalCartesian.html", "classGeographicLib_1_1LocalCartesian" ],
    [ "MagneticCircle", "classGeographicLib_1_1MagneticCircle.html", "classGeographicLib_1_1MagneticCircle" ],
    [ "MagneticModel", "classGeographicLib_1_1MagneticModel.html", "classGeographicLib_1_1MagneticModel" ],
    [ "Math", "classGeographicLib_1_1Math.html", "classGeographicLib_1_1Math" ],
    [ "MGRS", "classGeographicLib_1_1MGRS.html", "classGeographicLib_1_1MGRS" ],
    [ "NearestNeighbor", "classGeographicLib_1_1NearestNeighbor.html", "classGeographicLib_1_1NearestNeighbor" ],
    [ "NormalGravity", "classGeographicLib_1_1NormalGravity.html", "classGeographicLib_1_1NormalGravity" ],
    [ "OSGB", "classGeographicLib_1_1OSGB.html", "classGeographicLib_1_1OSGB" ],
    [ "PolarStereographic", "classGeographicLib_1_1PolarStereographic.html", "classGeographicLib_1_1PolarStereographic" ],
    [ "PolygonAreaT", "classGeographicLib_1_1PolygonAreaT.html", "classGeographicLib_1_1PolygonAreaT" ],
    [ "Rhumb", "classGeographicLib_1_1Rhumb.html", "classGeographicLib_1_1Rhumb" ],
    [ "RhumbLine", "classGeographicLib_1_1RhumbLine.html", "classGeographicLib_1_1RhumbLine" ],
    [ "SphericalEngine", "classGeographicLib_1_1SphericalEngine.html", "classGeographicLib_1_1SphericalEngine" ],
    [ "SphericalHarmonic", "classGeographicLib_1_1SphericalHarmonic.html", "classGeographicLib_1_1SphericalHarmonic" ],
    [ "SphericalHarmonic1", "classGeographicLib_1_1SphericalHarmonic1.html", "classGeographicLib_1_1SphericalHarmonic1" ],
    [ "SphericalHarmonic2", "classGeographicLib_1_1SphericalHarmonic2.html", "classGeographicLib_1_1SphericalHarmonic2" ],
    [ "TransverseMercator", "classGeographicLib_1_1TransverseMercator.html", "classGeographicLib_1_1TransverseMercator" ],
    [ "TransverseMercatorExact", "classGeographicLib_1_1TransverseMercatorExact.html", "classGeographicLib_1_1TransverseMercatorExact" ],
    [ "Utility", "classGeographicLib_1_1Utility.html", "classGeographicLib_1_1Utility" ],
    [ "UTMUPS", "classGeographicLib_1_1UTMUPS.html", "classGeographicLib_1_1UTMUPS" ],
    [ "Utility::val< std::string >", "namespaceGeographicLib.html#af1d6e0caab7f78097e6adb9870dacf1e", null ],
    [ "PolygonAreaT< Geodesic >", "namespaceGeographicLib.html#a6efa97bcc849da2bd4c64c1e50ec3a5e", null ],
    [ "PolygonAreaT< GeodesicExact >", "namespaceGeographicLib.html#a5bc694650c33ded175db3e77d624978f", null ],
    [ "PolygonAreaT< Rhumb >", "namespaceGeographicLib.html#a0a940e42abff2e761709708b3556f220", null ]
];

==> mingw-w64-clang-aarch64-geographiclib-2.5.2-1-any.pkg.tar.zst: clangarm64/share/doc/GeographicLib/html/namespaceGeographicLib.js <==
var namespaceGeographicLib =
[
    [ "experimental", "namespaceGeographicLib_1_1experimental.html", "namespaceGeographicLib_1_1experimental" ],
    [ "Accumulator", "classGeographicLib_1_1Accumulator.html", "classGeographicLib_1_1Accumulator" ],
    [ "AlbersEqualArea", "classGeographicLib_1_1AlbersEqualArea.html", "classGeographicLib_1_1AlbersEqualArea" ],
    [ "AuxAngle", "classGeographicLib_1_1AuxAngle.html", "classGeographicLib_1_1AuxAngle" ],
    [ "AuxLatitude", "classGeographicLib_1_1AuxLatitude.html", "classGeographicLib_1_1AuxLatitude" ],
    [ "AzimuthalEquidistant", "classGeographicLib_1_1AzimuthalEquidistant.html", "classGeographicLib_1_1AzimuthalEquidistant" ],
    [ "CassiniSoldner", "classGeographicLib_1_1CassiniSoldner.html", "classGeographicLib_1_1CassiniSoldner" ],
    [ "CircularEngine", "classGeographicLib_1_1CircularEngine.html", "classGeographicLib_1_1CircularEngine" ],
    [ "Constants", "classGeographicLib_1_1Constants.html", "classGeographicLib_1_1Constants" ],
    [ "DAuxLatitude", "classGeographicLib_1_1DAuxLatitude.html", "classGeographicLib_1_1DAuxLatitude" ],
    [ "DMS", "classGeographicLib_1_1DMS.html", "classGeographicLib_1_1DMS" ],
    [ "DST", "classGeographicLib_1_1DST.html", "classGeographicLib_1_1DST" ],
    [ "Ellipsoid", "classGeographicLib_1_1Ellipsoid.html", "classGeographicLib_1_1Ellipsoid" ],
    [ "EllipticFunction", "classGeographicLib_1_1EllipticFunction.html", "classGeographicLib_1_1EllipticFunction" ],
    [ "GARS", "classGeographicLib_1_1GARS.html", "classGeographicLib_1_1GARS" ],
    [ "Geocentric", "classGeographicLib_1_1Geocentric.html", "classGeographicLib_1_1Geocentric" ],
    [ "GeoCoords", "classGeographicLib_1_1GeoCoords.html", "classGeographicLib_1_1GeoCoords" ],
    [ "Geodesic", "classGeographicLib_1_1Geodesic.html", "classGeographicLib_1_1Geodesic" ],
    [ "GeodesicExact", "classGeographicLib_1_1GeodesicExact.html", "classGeographicLib_1_1GeodesicExact" ],
    [ "GeodesicLine", "classGeographicLib_1_1GeodesicLine.html", "classGeographicLib_1_1GeodesicLine" ],
    [ "GeodesicLineExact", "classGeographicLib_1_1GeodesicLineExact.html", "classGeographicLib_1_1GeodesicLineExact" ],
    [ "GeographicErr", "classGeographicLib_1_1GeographicErr.html", "classGeographicLib_1_1GeographicErr" ],
    [ "Geohash", "classGeographicLib_1_1Geohash.html", "classGeographicLib_1_1Geohash" ],
    [ "Geoid", "classGeographicLib_1_1Geoid.html", "classGeographicLib_1_1Geoid" ],
    [ "Georef", "classGeographicLib_1_1Georef.html", "classGeographicLib_1_1Georef" ],
    [ "Gnomonic", "classGeographicLib_1_1Gnomonic.html", "classGeographicLib_1_1Gnomonic" ],
    [ "GravityCircle", "classGeographicLib_1_1GravityCircle.html", "classGeographicLib_1_1GravityCircle" ],
    [ "GravityModel", "classGeographicLib_1_1GravityModel.html", "classGeographicLib_1_1GravityModel" ],
    [ "Intersect", "classGeographicLib_1_1Intersect.html", "classGeographicLib_1_1Intersect" ],
    [ "LambertConformalConic", "classGeographicLib_1_1LambertConformalConic.html", "classGeographicLib_1_1LambertConformalConic" ],
    [ "LocalCartesian", "classGeographicLib_1_1LocalCartesian.html", "classGeographicLib_1_1LocalCartesian" ],
    [ "MagneticCircle", "classGeographicLib_1_1MagneticCircle.html", "classGeographicLib_1_1MagneticCircle" ],
    [ "MagneticModel", "classGeographicLib_1_1MagneticModel.html", "classGeographicLib_1_1MagneticModel" ],
    [ "Math", "classGeographicLib_1_1Math.html", "classGeographicLib_1_1Math" ],
    [ "MGRS", "classGeographicLib_1_1MGRS.html", "classGeographicLib_1_1MGRS" ],
    [ "NearestNeighbor", "classGeographicLib_1_1NearestNeighbor.html", "classGeographicLib_1_1NearestNeighbor" ],
    [ "NormalGravity", "classGeographicLib_1_1NormalGravity.html", "classGeographicLib_1_1NormalGravity" ],
    [ "OSGB", "classGeographicLib_1_1OSGB.html", "classGeographicLib_1_1OSGB" ],
    [ "PolarStereographic", "classGeographicLib_1_1PolarStereographic.html", "classGeographicLib_1_1PolarStereographic" ],
    [ "PolygonAreaT", "classGeographicLib_1_1PolygonAreaT.html", "classGeographicLib_1_1PolygonAreaT" ],
    [ "Rhumb", "classGeographicLib_1_1Rhumb.html", "classGeographicLib_1_1Rhumb" ],
    [ "RhumbLine", "classGeographicLib_1_1RhumbLine.html", "classGeographicLib_1_1RhumbLine" ],
    [ "SphericalEngine", "classGeographicLib_1_1SphericalEngine.html", "classGeographicLib_1_1SphericalEngine" ],
    [ "SphericalHarmonic", "classGeographicLib_1_1SphericalHarmonic.html", "classGeographicLib_1_1SphericalHarmonic" ],
    [ "SphericalHarmonic1", "classGeographicLib_1_1SphericalHarmonic1.html", "classGeographicLib_1_1SphericalHarmonic1" ],
    [ "SphericalHarmonic2", "classGeographicLib_1_1SphericalHarmonic2.html", "classGeographicLib_1_1SphericalHarmonic2" ],
    [ "TransverseMercator", "classGeographicLib_1_1TransverseMercator.html", "classGeographicLib_1_1TransverseMercator" ],
    [ "TransverseMercatorExact", "classGeographicLib_1_1TransverseMercatorExact.html", "classGeographicLib_1_1TransverseMercatorExact" ],
    [ "Utility", "classGeographicLib_1_1Utility.html", "classGeographicLib_1_1Utility" ],
    [ "UTMUPS", "classGeographicLib_1_1UTMUPS.html", "classGeographicLib_1_1UTMUPS" ],
    [ "Utility::val< std::string >", "namespaceGeographicLib.html#af1d6e0caab7f78097e6adb9870dacf1e", null ],
    [ "Utility::str< Math::real >", "namespaceGeographicLib.html#ae0776ea265c45efa42f01a11aaeb0243", null ]
];
